@@ -5,14 +5,10 @@ use warnings;
 
 use 5.008;
 
-use vars qw($VERSION);
-
-$VERSION = '0.3.3';
+our $VERSION = 'v0.4.0';
 
 package HTML::Latemp::GenMakeHelpers::Base;
 
-use base 'Class::Accessor';
-
 sub new
 {
     my $class = shift;
@@ -24,11 +20,9 @@ sub new
 
 package HTML::Latemp::GenMakeHelpers::HostEntry;
 
-use vars qw(@ISA);
+our @ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
 
-@ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
-
-__PACKAGE__->mk_accessors(qw(id dest_dir source_dir));
+use Class::XSAccessor accessors => {'dest_dir' => 'dest_dir', 'id' => 'id', 'source_dir' => 'source_dir',};
 
 sub initialize
 {
@@ -42,20 +36,13 @@ sub initialize
 
 package HTML::Latemp::GenMakeHelpers::Error;
 
-use vars qw(@ISA);
-
-@ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
+our @ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
 
 package HTML::Latemp::GenMakeHelpers::Error::UncategorizedFile;
 
-use vars qw(@ISA);
+our @ISA=(qw(HTML::Latemp::GenMakeHelpers::Error));
 
-@ISA=(qw(HTML::Latemp::GenMakeHelpers::Error));
-
-__PACKAGE__->mk_accessors(qw(
-    file
-    host
-));
+use Class::XSAccessor accessors => {'file' => 'file', 'host' => 'host',};
 
 sub initialize
 {
@@ -71,15 +58,12 @@ sub initialize
 package HTML::Latemp::GenMakeHelpers;
 
 
-
-use vars qw(@ISA);
-
-@ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
+our @ISA=(qw(HTML::Latemp::GenMakeHelpers::Base));
 
 use File::Find::Rule;
 use File::Basename;
 
-__PACKAGE__->mk_accessors(qw(base_dir _common_buckets hosts hosts_id_map));
+use Class::XSAccessor accessors => {'_common_buckets' => '_common_buckets', '_base_dir' => 'base_dir', 'hosts' => 'hosts', '_hosts_id_map' => 'hosts_id_map',};
 
 
 sub initialize
@@ -87,7 +71,7 @@ sub initialize
     my $self = shift;
     my (%args) = (@_);
 
-    $self->base_dir("src");
+    $self->_base_dir("src");
     $self->hosts(
         [
         map {
@@ -98,7 +82,7 @@ sub initialize
         @{$args{'hosts'}}
         ]
         );
-    $self->hosts_id_map(+{ map { $_->{'id'} => $_ } @{$self->hosts()}});
+    $self->_hosts_id_map(+{ map { $_->{'id'} => $_ } @{$self->hosts()}});
     $self->_common_buckets({});
 
     return;
@@ -107,14 +91,14 @@ sub initialize
 sub process_all
 {
     my $self = shift;
-    my $dir = $self->base_dir();
+    my $dir = $self->_base_dir();
 
     my @hosts = @{$self->hosts()};
 
     open my $file_lists_fh, ">", "include.mak";
     open my $rules_fh, ">", "rules.mak";
 
-    print {$rules_fh} "COMMON_SRC_DIR = " . $self->hosts_id_map()->{'common'}->{'source_dir'} . "\n\n";
+    print {$rules_fh} "COMMON_SRC_DIR = " . $self->_hosts_id_map()->{'common'}->{'source_dir'} . "\n\n";
 
     foreach my $host (@hosts)
     {
@@ -140,7 +124,6 @@ sub _make_path
 }
 
 
-
 sub get_initial_buckets
 {
     my $self = shift;
@@ -385,7 +368,7 @@ sub process_host
     my $self = shift;
     my $host = shift;
 
-    my $dir = $self->base_dir();
+    my $dir = $self->_base_dir();
 
     my $source_dir_path = $host->source_dir();
 
@@ -434,7 +417,7 @@ HTML::Latemp::GenMakeHelpers - A Latemp Utility Module.
 
 =head1 VERSION
 
-version 0.3.3
+version v0.4.0
 
 =head1 SYNOPSIS
 
@@ -469,6 +452,11 @@ Process all hosts.
 Called by the constructor to initialize the object. Can be sub-classes by
 derived classes.
 
+=head2 $generator->hosts()
+
+Returns an array reference of HTML::Latemp::GenMakeHelpers::HostEntry for
+the hosts.
+
 =head2 $generator->get_initial_buckets($host)
 
 Get the initial buckets for the host $host.
